==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tutti i font</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Cinese</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospazio</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>File corrotto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Medesima versione già installata</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Font di sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PagSù</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PagGiù</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Indietro</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Font %1 installato</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Font %1 installato</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Sicuro di voler eliminare questo font?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Questo font non sarà disponibile nelle App</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Questi font non saranno disponibili per le App</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>L&apos;altro font di sistema %1 non può essere eliminato</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>ll font &quot;%1&quot; è in uso e non può essere eliminato</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>L&apos;altro font di sistema 51 ed il font in uso &quot;%2&quot; non possono essere eliminati</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Sicuro di voler eliminare %1 font?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Eliiminazione font, attendere...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verifica font</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Non ci sono font da installare</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>No lasciare che i tuoi desideri restino solo sogni</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Info base</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stile</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS Nome</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Licenza</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Font Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Font Manager supporto l&apos;utenza nell&apos;installazione e gestione dei font di Sistema.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Caricamento font, attendere...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Font esportato sul desktop</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 font esportati sul desktop</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Esportazione di 1 font fallita per spazio insufficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Esportazione di %1 font fallita per spazio insufficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Aggiungi font</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disabilita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non più preferito</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel File Manager</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>disattivato</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>I font sono stati disattivati</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 è in uso, non puoi disabilitarlo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Non puoi disabilitare i font di sistema e quelli in uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Non puoi disabilitare i font di sistema</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Alcuni font non possono essere disattivati</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installa font</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verifica...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>File corrotto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installato</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non installato</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installa font</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nessun font</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina su</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina giù</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Aggiungi font</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non più preferito</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Info font</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Inserisci testo di prova</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>File corrotto</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tutti i font</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Cinese</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospazio</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 è una famiglia di Font, procedendo saranno eliminati tutti i Font in essa contenuti</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 è una famiglia di font, procedendo saranno abilitati tutti i font in essa contenuti</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 è una famiglia di font, procedendo saranno disabilitati tutti i font in essa contenuti</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Abilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Disabilita</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Applica a tutte le famiglie di font selezionate</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>File corrotto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Medesima versione già installata</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Font di sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PagSù</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PagGiù</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Font %1 installato</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Font %1 installato</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Impossibile installare il carattere %1. Non c&apos;è abbastanza spazio su disco.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Installazione di %1 font fallita per spazio insufficiente.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Questo font non sarà disponibile nelle App</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Questi font non saranno disponibili per le App</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>L&apos;altro font di sistema %1 non può essere eliminato</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>ll font &quot;%1&quot; è in uso e non può essere eliminato</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>L&apos;altro font di sistema 51 ed il font in uso &quot;%2&quot; non possono essere eliminati</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Sicuro di voler eliminare %1 font?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Eliiminazione font, attendere...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verifica font</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Non ci sono font da installare</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continua</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Info base</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stile</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS Nome</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Licenza</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Font Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Font Manager supporto l&apos;utenza nell&apos;installazione e gestione dei font di Sistema.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Caricamento font, attendere...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Font esportato sul desktop</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 font esportati sul desktop</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Esportazione di 1 font fallita per spazio insufficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Esportazione di %1 font fallita per spazio insufficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Aggiungi font</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disabilita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non più preferito</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel File Manager</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>disattivato</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>I font sono stati disattivati</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 è in uso, non puoi disabilitarlo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Non puoi disabilitare i font di sistema e quelli in uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Non puoi disabilitare i font di sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installa font</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verifica...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>File corrotto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installato</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non installato</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installa font</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nessun font</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina su</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina giù</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Aggiungi font</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non più preferito</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Info font</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Inserisci testo di prova</translation>
    </message>
</context>
</TS>
